@@ -10,35 +10,35 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.21';
-$DATE = '2004/04/13';
+$VERSION = '0.22';
+$DATE = '2004/04/15';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.21 2004/04/13), 'revised 0.20'],
-    'MANIFEST' => [qw(0.21 2004/04/13), 'generated, replaces 0.20'],
-    'Makefile.PL' => [qw(0.21 2004/04/13), 'generated, replaces 0.20'],
-    'README' => [qw(0.21 2004/04/13), 'generated, replaces 0.20'],
-    'lib/Test/Tech.pm' => [qw(1.18 2004/04/13), 'revised 1.17'],
-    't/Test/Tech/Tech.d' => [qw(0.05 2004/04/13), 'revised 0.04'],
-    't/Test/Tech/Tech.pm' => [qw(0.04 2004/04/13), 'revised 0.03'],
-    't/Test/Tech/Tech.t' => [qw(0.18 2004/04/13), 'revised 0.17'],
-    't/Test/Tech/techA0.t' => [qw(0.12 2004/04/13), 'revised 0.11'],
-    't/Test/Tech/techA2.txt' => [qw(0.08 2004/04/07), 'unchanged'],
-    't/Test/Tech/techB0.t' => [qw(0.09 2004/04/13), 'revised 0.08'],
-    't/Test/Tech/techC0.t' => [qw(0.13 2004/04/13), 'revised 0.12'],
-    't/Test/Tech/techC2.txt' => [qw(0.1 2004/04/13), 'revised 0.09'],
-    't/Test/Tech/techD0.d' => [qw(0.06 2004/04/13), 'revised 0.05'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.22 2004/04/15), 'revised 0.21'],
+    'MANIFEST' => [qw(0.22 2004/04/15), 'generated, replaces 0.21'],
+    'Makefile.PL' => [qw(0.22 2004/04/15), 'generated, replaces 0.21'],
+    'README' => [qw(0.22 2004/04/15), 'generated, replaces 0.21'],
+    'lib/Test/Tech.pm' => [qw(1.19 2004/04/15), 'revised 1.18'],
+    't/Test/Tech/Tech.d' => [qw(0.06 2004/04/15), 'revised 0.05'],
+    't/Test/Tech/Tech.pm' => [qw(0.05 2004/04/15), 'revised 0.04'],
+    't/Test/Tech/Tech.t' => [qw(0.19 2004/04/15), 'revised 0.18'],
+    't/Test/Tech/techA0.t' => [qw(0.13 2004/04/15), 'revised 0.12'],
+    't/Test/Tech/techA2.txt' => [qw(0.09 2004/04/15), 'revised 0.08'],
+    't/Test/Tech/techB0.t' => [qw(0.09 2004/04/13), 'unchanged'],
+    't/Test/Tech/techC0.t' => [qw(0.13 2004/04/13), 'unchanged'],
+    't/Test/Tech/techC2.txt' => [qw(0.11 2004/04/15), 'revised 0.1'],
+    't/Test/Tech/techD0.d' => [qw(0.06 2004/04/13), 'unchanged'],
     't/Test/Tech/techD2.txt' => [qw(0.07 2003/09/15), 'unchanged'],
     't/Test/Tech/techD3.txt' => [qw(0.07 2003/09/15), 'unchanged'],
-    't/Test/Tech/techE0.t' => [qw(0.08 2004/04/13), 'revised 0.07'],
-    't/Test/Tech/techE2.txt' => [qw(0.18 2004/04/13), 'revised 0.17'],
-    't/Test/Tech/File/Package.pm' => [qw(1.16 2004/04/13), 'revised 1.15'],
-    't/Test/Tech/File/SmartNL.pm' => [qw(1.13 2004/04/13), 'unchanged'],
-    't/Test/Tech/Text/Scrub.pm' => [qw(1.11 2004/04/13), 'unchanged'],
-    't/Test/Tech/Data/Secs2.pm' => [qw(1.16 2004/04/13), 'revised 1.15'],
-    't/Test/Tech/Data/SecsPack.pm' => [qw(0.02 2004/04/13), 'new'],
+    't/Test/Tech/techE0.t' => [qw(0.08 2004/04/13), 'unchanged'],
+    't/Test/Tech/techE2.txt' => [qw(0.19 2004/04/15), 'revised 0.18'],
+    't/Test/Tech/File/Package.pm' => [qw(1.16 2004/04/15), 'unchanged'],
+    't/Test/Tech/File/SmartNL.pm' => [qw(1.13 2004/04/15), 'unchanged'],
+    't/Test/Tech/Text/Scrub.pm' => [qw(1.11 2004/04/15), 'unchanged'],
+    't/Test/Tech/Data/Secs2.pm' => [qw(1.17 2004/04/15), 'revised 1.16'],
+    't/Test/Tech/Data/SecsPack.pm' => [qw(0.02 2004/04/15), 'unchanged'],
     't/Test/Tech/V001024/Test.pm' => [qw(1.25 2003/09/15), 'unchanged'],
     't/Test/Tech/V001015/Test.pm' => [qw(1.16 2003/09/15), 'unchanged'],
 
@@ -67,11 +67,11 @@ use vars qw(%INVENTORY);
 
  Test::Tech - Extends the Test program module
 
- Revision: U
+ Revision: V
 
- Version: 0.21
+ Version: 0.22
 
- Date: 2004/04/13
+ Date: 2004/04/15
 
  Prepared for: General Public 
 
@@ -138,7 +138,7 @@ session using the methods under test
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.21
+This document releases Test::Tech version 0.22
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -153,7 +153,7 @@ system file specification.
 
 This document releases the file 
 
- Test-Tech-0.21.tar.gz
+ Test-Tech-0.22.tar.gz
 
 found at the following repository(s):
 
@@ -225,29 +225,29 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.21    2004/04/13 revised 0.20
- MANIFEST                                                     0.21    2004/04/13 generated, replaces 0.20
- Makefile.PL                                                  0.21    2004/04/13 generated, replaces 0.20
- README                                                       0.21    2004/04/13 generated, replaces 0.20
- lib/Test/Tech.pm                                             1.18    2004/04/13 revised 1.17
- t/Test/Tech/Tech.d                                           0.05    2004/04/13 revised 0.04
- t/Test/Tech/Tech.pm                                          0.04    2004/04/13 revised 0.03
- t/Test/Tech/Tech.t                                           0.18    2004/04/13 revised 0.17
- t/Test/Tech/techA0.t                                         0.12    2004/04/13 revised 0.11
- t/Test/Tech/techA2.txt                                       0.08    2004/04/07 unchanged
- t/Test/Tech/techB0.t                                         0.09    2004/04/13 revised 0.08
- t/Test/Tech/techC0.t                                         0.13    2004/04/13 revised 0.12
- t/Test/Tech/techC2.txt                                       0.1     2004/04/13 revised 0.09
- t/Test/Tech/techD0.d                                         0.06    2004/04/13 revised 0.05
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.22    2004/04/15 revised 0.21
+ MANIFEST                                                     0.22    2004/04/15 generated, replaces 0.21
+ Makefile.PL                                                  0.22    2004/04/15 generated, replaces 0.21
+ README                                                       0.22    2004/04/15 generated, replaces 0.21
+ lib/Test/Tech.pm                                             1.19    2004/04/15 revised 1.18
+ t/Test/Tech/Tech.d                                           0.06    2004/04/15 revised 0.05
+ t/Test/Tech/Tech.pm                                          0.05    2004/04/15 revised 0.04
+ t/Test/Tech/Tech.t                                           0.19    2004/04/15 revised 0.18
+ t/Test/Tech/techA0.t                                         0.13    2004/04/15 revised 0.12
+ t/Test/Tech/techA2.txt                                       0.09    2004/04/15 revised 0.08
+ t/Test/Tech/techB0.t                                         0.09    2004/04/13 unchanged
+ t/Test/Tech/techC0.t                                         0.13    2004/04/13 unchanged
+ t/Test/Tech/techC2.txt                                       0.11    2004/04/15 revised 0.1
+ t/Test/Tech/techD0.d                                         0.06    2004/04/13 unchanged
  t/Test/Tech/techD2.txt                                       0.07    2003/09/15 unchanged
  t/Test/Tech/techD3.txt                                       0.07    2003/09/15 unchanged
- t/Test/Tech/techE0.t                                         0.08    2004/04/13 revised 0.07
- t/Test/Tech/techE2.txt                                       0.18    2004/04/13 revised 0.17
- t/Test/Tech/File/Package.pm                                  1.16    2004/04/13 revised 1.15
- t/Test/Tech/File/SmartNL.pm                                  1.13    2004/04/13 unchanged
- t/Test/Tech/Text/Scrub.pm                                    1.11    2004/04/13 unchanged
- t/Test/Tech/Data/Secs2.pm                                    1.16    2004/04/13 revised 1.15
- t/Test/Tech/Data/SecsPack.pm                                 0.02    2004/04/13 new
+ t/Test/Tech/techE0.t                                         0.08    2004/04/13 unchanged
+ t/Test/Tech/techE2.txt                                       0.19    2004/04/15 revised 0.18
+ t/Test/Tech/File/Package.pm                                  1.16    2004/04/15 unchanged
+ t/Test/Tech/File/SmartNL.pm                                  1.13    2004/04/15 unchanged
+ t/Test/Tech/Text/Scrub.pm                                    1.11    2004/04/15 unchanged
+ t/Test/Tech/Data/Secs2.pm                                    1.17    2004/04/15 revised 1.16
+ t/Test/Tech/Data/SecsPack.pm                                 0.02    2004/04/15 unchanged
  t/Test/Tech/V001024/Test.pm                                  1.25    2003/09/15 unchanged
  t/Test/Tech/V001015/Test.pm                                  1.16    2003/09/15 unchanged
 
@@ -598,6 +598,14 @@ grabs the output and compares to expected ouput stored in files.
 Corrected the C<FindBin> for following test software: 
 C<TechA0.t TechB0.t TechC0.t TechD0.d TechE0.t>
 
+=item Test-Tech-0.22
+
+The C<Data::SecsPack> program module is now required to run the C<Test::Tech>
+program module. Added a print out of the C<Data::SecsPack> version to the
+C<plan> subroutine as follows:
+
+ # Data::Secs2   : $Data::SecsPack::VERSION
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -636,13 +644,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Test-Tech-0.21.tar.gz' and download to a temporary
+Right click on 'Test-Tech-0.22.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Test-Tech-0.21.tar.gz
- tar -xf Test-Tech-0.21.tar
+ gunzip Test-Tech-0.22.tar.gz
+ tar -xf Test-Tech-0.22.tar
  perl Makefile.PL
  $make test
  $make install
@@ -759,11 +767,11 @@ __DATA__
 DISTNAME: Test-Tech^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.21^
+VERSION : 0.22^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.20^
-REVISION: U^
+PREVIOUS_RELEASE: 0.21^
+REVISION: V^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
@@ -1162,6 +1170,14 @@ grabs the output and compares to expected ouput stored in files.
 Corrected the C<FindBin> for following test software: 
 C<TechA0.t TechB0.t TechC0.t TechD0.d TechE0.t>
 
+\=item Test-Tech-0.22
+
+The C<Data::SecsPack> program module is now required to run the C<Test::Tech>
+program module. Added a print out of the C<Data::SecsPack> version to the
+C<plan> subroutine as follows:
+
+ # Data::Secs2   : $Data::SecsPack::VERSION
+
 \=back
 
 ^
